"""Context processors for the base application."""

from typing import Dict, Callable
from flask import current_app
from arxiv.base import config
from arxiv.base.exceptions import ConfigurationError


def config_url_builder() -> Dict[str, Callable]:
    """Inject a configurable URL factory."""
    def config_url(target: str) -> str:
        """Generate a URL from this app's configuration."""
        target = target.upper()
        # Look for the URL on the config of the current app (this will *not* be
        # base); fall back to the base config if not found.
        try:
            url: str = current_app.config.get(f'ARXIV_{target}_URL')
            if url is None:
                url = getattr(config, f'ARXIV_{target}_URL')
        except AttributeError as e:
            raise ConfigurationError(f'URL for {target} not set') from e
        return url
    return dict(config_url=config_url)



"""Flask configuration."""

import os

SERVER_NAME = None

ARXIV_TWITTER_URL = os.environ.get('ARXIV_TWITTER_URL',
                                   'https://twitter.com/arxiv')
ARXIV_SEARCH_BOX_URL = os.environ.get('SEARCH_BOX_URL', '/search')
ARXIV_SEARCH_ADVANCED_URL = os.environ.get('ARXIV_SEARCH_ADVANCED_URL',
                                           '/search/advanced')
ARXIV_ACCOUNT_URL = os.environ.get('ACCOUNT_URL', '/user')
ARXIV_LOGIN_URL = os.environ.get('LOGIN_URL', '/user/login')
ARXIV_LOGOUT_URL = os.environ.get('LOGOUT_URL', '/user/logout')
ARXIV_HOME_URL = os.environ.get('ARXIV_HOME_URL', 'https://arxiv.org')
ARXIV_HELP_URL = os.environ.get('ARXIV_HELP_URL', '/help')
ARXIV_CONTACT_URL = os.environ.get('ARXIV_CONTACT_URL', '/help/contact')
ARXIV_BLOG_URL = os.environ.get('ARXIV_BLOG_URL',
                                "https://blogs.cornell.edu/arxiv/")
ARXIV_WIKI_URL = os.environ.get(
    'ARXIV_WIKI_URL',
    "https://confluence.cornell.edu/display/arxivpub/arXiv+Public+Wiki"
)
ARXIV_ACCESSIBILITY_URL = os.environ.get(
    'ARXIV_ACCESSIBILITY_URL',
    "mailto:web-accessibility@cornell.edu"
)
ARXIV_LIBRARY_URL = os.environ.get('ARXIV_LIBRARY_URL',
                                   'https://library.cornell.edu')
ARXIV_ACKNOWLEDGEMENT_URL = os.environ.get(
    'ARXIV_ACKNOWLEDGEMENT_URL',
    "https://confluence.cornell.edu/x/ALlRF"
)
